@@ -1,6 +1,7 @@
 import logging
-from linux_profile.base.config import BaseConfig
+
 from logging.config import dictConfig
+from linux_profile.base.config import BaseConfig
 from linux_profile.settings import file_location
 
 
@@ -37,8 +38,6 @@ class LogBaseConfig(BaseConfig):
 def setup_log(name_log: str, file_log: str, level: logging):
     LogBaseConfig()
 
-    # logging.config.dictConfig(logging_config)
-
     log_handler = logging.FileHandler(file_log)
     log_handler.setFormatter(log_format)
 
@@ -51,13 +50,6 @@ def setup_log(name_log: str, file_log: str, level: logging):
 def run_app(name_log: str):
     return setup_log(
         name_log=name_log,
-        file_log=file_location.get("log_config"),
-        level=logging.WARNING
-    )
-
-def run_profile(name_log: str):
-    return setup_log(
-        name_log=name_log,
-        file_log=file_location.get("log_profile"),
+        file_log=file_location.get("log_app"),
         level=logging.DEBUG
     )
